Utilities
=========

.. automodule:: metacells.utilities

.. automodule:: metacells.utilities.annotation
    :members:

.. automodule:: metacells.utilities.computation
    :members:

.. automodule:: metacells.utilities.typing
    :members:

.. automodule:: metacells.utilities.parallel
    :members:

.. automodule:: metacells.utilities.progress
    :members:

.. automodule:: metacells.utilities.timing
    :members:

.. automodule:: metacells.utilities.logging
    :members:

.. automodule:: metacells.utilities.documentation
    :members:
